/***************************************************************************
                          guiinput.h  -  description
                             -------------------
    begin                : Tue Jun 15 2004
    copyright            : (C) 2004 by Harald Krippel
    email                : harald@hte-develop.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GUIINPUT_H
#define GUIINPUT_H

/**
  *@author Harald Krippel
  */

#include <plib/pu.h>

/*!

 This Class is the glue between PLIB puInput and QCake.

*/
class GUIInput : public puInput  {
public: 
	GUIInput(int minx, int miny, int maxx, int maxy);
  void setText(const char *text);
	~GUIInput();
private:
  char labeltext[256];

};

#endif
